/* See LICENSE file for copyright and license details. */

/* appearance */
static const unsigned int borderpx  = 1;        /* border pixel of windows */
static const unsigned int snap      = 32;       /* snap pixel */
static const int showbar            = 1;        /* 0 means no bar */
static const int topbar             = 1;        /* 0 means bottom bar */
static const char *fonts[]          = { "monospace:size=10" };
static const char dmenufont[]       = "monospace:size=10";

static const char col_gray1[]       = "#222222";
static const char col_gray2[]       = "#444444";
static const char col_gray3[]       = "#bbbbbb";
static const char col_gray4[]       = "#eeeeee";
static const char col_cyan[]        = "#005577";

static const char col_blue1[]       = "#102D4F";
static const char col_blue2[]       = "#00537A";
static const char col_yellow1[]     = "#F5A201";
static const char col_yellow2[]     = "#FFBA42";
static const char col_blush[]       = "#F8E5EE";

static const char col_dark1[]       = "#162736";
static const char col_dark2[]       = "#203449";
static const char col_dark3[]       = "#708594";
static const char col_white[]       = "#FFFFFF";

static const char *colors[][3]      = {
	/*               fg         bg         border   */
    [SchemeNorm] = { col_white, col_dark1, col_dark1 },
	[SchemeSel ] = { col_white, col_dark3, col_dark3 },
};

/* tagging */
static const char *tags[] = { "1", "2", "3", "4", "5" };

static const Rule rules[] = {
	/* xprop(1):
	 *	WM_CLASS(STRING) = instance, class
	 *	WM_NAME(STRING) = title
	 */
	/* class      instance    title       tags mask     isfloating   monitor */
	{ "Gimp",     NULL,       NULL,       0,            1,           -1 },
	{ "Firefox",  NULL,       NULL,       1 << 8,       0,           -1 },
};

/* layout(s) */
static const float	mfact			= 0.55; /* factor of master area size [0.05..0.95] */
static const int 	nmaster			= 1;    /* number of clients in master area */
static const int 	resizehints		= 1;    /* 1 means respect size hints in tiled resizals */
static const int 	lockfullscreen	= 1;    /* 1 will force focus on the fullscreen window */
static const Layout layouts[] 		= {
	/* symbol     arrange function */
	{ "[]=",      tile 		},    /* first entry is default */
	{ "><>",      NULL		},    /* no layout function means floating behavior */
	{ "[M]",      monocle	},
};

/* key definitions */
#define MODKEY Mod4Mask
#define TAGKEYS(KEY,TAG) \
	{ MODKEY,                       KEY,      view,           {.ui = 1 << TAG} }, \
	{ MODKEY|ControlMask,           KEY,      toggleview,     {.ui = 1 << TAG} }, \
	{ MODKEY|ShiftMask,             KEY,      tag,            {.ui = 1 << TAG} }, \
	{ MODKEY|ControlMask|ShiftMask, KEY,      toggletag,      {.ui = 1 << TAG} },

/* helper for spawning shell commands in the pre dwm-5.0 fashion */
#define SHCMD(cmd) { .v = (const char*[]){ "/bin/sh", "-c", cmd, NULL } }

/* commands */
static       char dmenumon[2]	= "0"; /* component of dmenucmd, manipulated in spawn() */

static const char *dmenucmd[] 	= { "dmenu_run",
									"-m", dmenumon,
									"-fn", dmenufont,
									"-nb", col_gray1,
									"-nf", col_gray3,
									"-sb", col_cyan,
									"-sf", col_gray4, NULL };

static const char *roficmd[]	= { "rofi",
									"-modi", "drun,power:~/.config/rofi/power-menu",
									"-show", "drun",
									"-show-icons",
									"-theme", "Arc-Dark.rasi",
									"-columns", "2",
									"-lines", "10",
									"-window-thumbnail",
									/*"-font", "'Open Sans 18'",*/
									"-opacity",
									"-width", "80",
									"-sidebar-mode", NULL };

static const char *termcmd[]	= { "kitty"  				, NULL };
static const char *filecmd[]	= { "thunar" 				, NULL };

static const char *sca[]		= { "scrot"					, NULL };
static const char *scr[]		= { "scrot"	, "-s"			, NULL };

static const char *nmtui[]		= { "kitty"	, "nmtui"		, NULL };
static const char *nmcedit[]	= { "nm-connection-editor"	, NULL };

static const char *top[]		= { "kitty"	, "htop" 		, NULL };

static const char *intip[]		= { "bash"	, "/home/aji/.dwm/aji.sh", "info"};
#include "aji.c"

static const Key keys[] 		= {
	/* modifier                     key        function        argument */
	{ MODKEY,						XK_i,						spawn,		{.v = intip}		},
	{ MODKEY,						XK_BackSpace,				view,		{0}					},
	{ MODKEY,						XK_a,						view,		{.ui = ~0}			}, // Select all tags. Cancel it with `MODKEY + [tag key]`.
	{ MODKEY|Mod1Mask,				XK_p,					    tag,		{.ui = ~0}			}, // Pin current window to all tags. Cancel it with `MODKEY + Shift + [tag key]`.

	{ MODKEY,						XK_Left,					focusmon,	{.i = -1}			},
	{ MODKEY,						XK_Right,					focusmon,	{.i = +1}			},
	{ MODKEY|ShiftMask,				XK_Left,					tagmon,		{.i = -1}			},
	{ MODKEY|ShiftMask,				XK_Right,					tagmon,		{.i = +1}			},

	{ MODKEY,						XK_p,						spawn,		{.v = roficmd}		},
	{ MODKEY|ShiftMask,				XK_p,						spawn,		{.v = dmenucmd}		},

	{ MODKEY,						XK_k,						spawn,		{.v = termcmd}		},
	{ MODKEY,						XK_e,						spawn,		{.v = filecmd}		},
	{ MODKEY,						XK_n,						spawn,		{.v = nmtui}		},
	{ MODKEY|ShiftMask,				XK_n,						spawn,		{.v = nmcedit}		},
	{ MODKEY,						XK_h,						spawn,		{.v = top}			},

	{ 0,							XK_Print,					spawn,		{.v = sca}			},
	{ MODKEY|ShiftMask,				XK_s,						spawn,		{.v = scr}			},
	{ MODKEY,						XK_b,						togglebar,	{0}					},
	{ MODKEY,						XK_Prior,					focusstack,	{.i = -1}			},
	{ MODKEY,						XK_Next,					focusstack,	{.i = +1}			},
	{ MODKEY,						XK_Down,					focusstack,	{.i = -1}			},
	{ MODKEY,						XK_Up,						focusstack,	{.i = +1}			},
	{ Mod1Mask,						XK_Tab,					    focusstack,	{.i = +1}			},
	{ Mod1Mask|ShiftMask,			XK_Tab,					    focusstack,	{.i = -1}			},

	{ MODKEY,						XK_Return,					zoom,		{0}					},

	{ MODKEY|ControlMask,			XK_Left,					shiftview,	{.i = -1}			},
	{ MODKEY|ControlMask,			XK_Right,					shiftview,	{.i = +1}			},

	{ MODKEY|ShiftMask,				XK_Tab,						shiftview,	{.i = -1}			},
	{ MODKEY,						XK_Tab,						shiftview,	{.i = +1}			},

	{ MODKEY|ControlMask|ShiftMask,	XK_Left,					shifttag,	{.i = -1}			},
	{ MODKEY|ControlMask|ShiftMask,	XK_Right,					shifttag,	{.i = +1}			},

	{ MODKEY|Mod1Mask, 				XK_v, 						cyclelayout, {0} },

	{ MODKEY,						XK_w,						killclient,	{0}					},
	{ MODKEY|ShiftMask,				XK_q,						quit,		{0}					},

	{ MODKEY|Mod1Mask,				XK_Up,						incnmaster,	{.i = +1}			},
	{ MODKEY|Mod1Mask,				XK_Down,					incnmaster,	{.i = -1}			},
	{ MODKEY|Mod1Mask,				XK_Left,					setmfact,	{.f = -0.05}		},
	{ MODKEY|Mod1Mask,				XK_Right,					setmfact,	{.f = +0.05}		},

	TAGKEYS(XK_1, 0)
	TAGKEYS(XK_2, 1)
	TAGKEYS(XK_3, 2)
	TAGKEYS(XK_4, 3)
	TAGKEYS(XK_5, 4)
};

/* button definitions */
/* click can be ClkTagBar, ClkLtSymbol, ClkStatusText, ClkWinTitle, ClkClientWin, or ClkRootWin */
static const Button buttons[] = {
	/* click                event mask      button          function        argument */
	{ ClkLtSymbol,          0,              Button1,        setlayout,      {0} },
	{ ClkLtSymbol,          0,              Button3,        setlayout,      {.v = &layouts[2]} },
	{ ClkWinTitle,          0,              Button2,        zoom,           {0} },
	{ ClkStatusText,        0,              Button2,        spawn,          {.v = termcmd } },
	{ ClkClientWin,         MODKEY,         Button1,        movemouse,      {0} },
	{ ClkClientWin,         MODKEY,         Button2,        togglefloating, {0} },
	{ ClkClientWin,         MODKEY,         Button3,        resizemouse,    {0} },
	{ ClkTagBar,            0,              Button1,        view,           {0} },
	{ ClkTagBar,            0,              Button3,        toggleview,     {0} },
	{ ClkTagBar,            MODKEY,         Button1,        tag,            {0} },
	{ ClkTagBar,            MODKEY,         Button3,        toggletag,      {0} },
};

